@@ -20,7 +20,7 @@ INVALID_ID_STRINGS = (
 	"OEM", "O.E.M.", "o.e.m.",
 	"N/A", "n/a",
 	"12345", "54321", "202020",
-	"chassis",
+	"Chassis", "chassis",
 )
 
 class Singleton(type):
@@ -190,11 +190,6 @@ class System(object):
 			id = read_from_file(os.path.join(SYS_CLASS_DMI, file))
 			ids.append(id)
 
-		# Use serial number from root disk (if available)
-		root_disk_serial = self.root_disk_serial
-		if root_disk_serial:
-			ids.append(root_disk_serial)
-
 		# Sort out all bogous or invalid strings from the list.
 		_ids = []
 		for id in ids:
@@ -211,6 +206,11 @@ class System(object):
 
 		ids = _ids
 
+		# Use serial number from root disk (if available)
+		root_disk_serial = self.root_disk_serial
+		if root_disk_serial:
+			ids.append(root_disk_serial)
+
 		# As last resort, we use the UUID from pakfire.
 		if not ids:
 			id = read_from_file("/opt/pakfire/db/uuid")
